searchData={"items":[{"type":"module","title":"VegaLite","doc":"Elixir bindings to [Vega-Lite](https://vega.github.io/vega-lite).\n\nVega-Lite offers a high-level grammar for composing interactive graphics,\nwhere every graphic is specified in a declarative fashion relying solely\non JSON syntax. To learn more about Vega-Lite please refer to\nthe [documentation](https://vega.github.io/vega-lite/docs)\nand explore numerous [examples](https://vega.github.io/vega-lite/examples).\n\nThis package offers a tiny layer of functionality that makes it easier\nto build a Vega-Lite graphics specification.","ref":"VegaLite.html"},{"type":"module","title":"Composing graphics - VegaLite","doc":"We offers a light-weight pipeline API akin to the JSON specification.\nTranslating existing Vega-Lite specifications to such specification\nshould be very intuitive in most cases.\n\nComposing a basic Vega-Lite graphic usually consists of the following steps:\n\n    alias VegaLite, as: Vl\n\n    # Initialize the specification, optionally with some top-level properties\n    Vl.new(width: 400, height: 400)\n\n    # Specify data source for the graphic, see the data_from_* functions\n    |> Vl.data_from_values(iteration: 1..100, score: 1..100)\n    # |> Vl.data_from_values([%{iteration: 1, score: 1}, ...])\n    # |> Vl.data_from_url(\"...\")\n\n    # Pick a visual mark for the graphic\n    |> Vl.mark(:line)\n    # |> Vl.mark(:point, tooltip: true)\n\n    # Map data fields to visual properties of the mark, like position or shape\n    |> Vl.encode_field(:x, \"iteration\", type: :quantitative)\n    |> Vl.encode_field(:y, \"score\", type: :quantitative)\n    # |> Vl.encode_field(:color, \"country\", type: :nominal)\n    # |> Vl.encode_field(:size, \"count\", type: :quantitative)\n\nThen, you can compose multiple graphics using `layers/2`, `concat/3`,\n`repeat/3` or `facet/3`.\n\n    Vl.new()\n    |> Vl.data_from_url(\"https://vega.github.io/editor/data/weather.csv\")\n    |> Vl.transform(filter: \"datum.location == 'Seattle'\")\n    |> Vl.concat([\n      Vl.new()\n      |> Vl.mark(:bar)\n      |> Vl.encode_field(:x, \"date\", time_unit: :month, type: :ordinal)\n      |> Vl.encode_field(:y, \"precipitation\", aggregate: :mean),\n      Vl.new()\n      |> Vl.mark(:point)\n      |> Vl.encode_field(:x, \"temp_min\", bin: true)\n      |> Vl.encode_field(:y, \"temp_max\", bin: true)\n      |> Vl.encode(:size, aggregate: :count)\n    ])\n\nAdditionally, you can use `transform/2` to preprocess the data,\n`param/3` for introducing interactivity and `config/2` for\nglobal customization.\n\n#","ref":"VegaLite.html#module-composing-graphics"},{"type":"module","title":"Using JSON specification - VegaLite","doc":"Alternatively you can parse a Vega-Lite JSON specification directly.\nThis approach makes it easy to explore numerous examples available online.\n\n    alias VegaLite, as: Vl\n\n    Vl.from_json(\"\"\"\n    {\n      \"data\": { \"url\": \"https://vega.github.io/editor/data/cars.json\" },\n      \"mark\": \"point\",\n      \"encoding\": {\n        \"x\": { \"field\": \"Horsepower\", \"type\": \"quantitative\" },\n        \"y\": { \"field\": \"Miles_per_Gallon\", \"type\": \"quantitative\" }\n      }\n    }\n    \"\"\")\n\nThe result of `VegaLite.from_json/1` function can then be passed\nthrough any other function to further customize the specification.\nIn particular, it may be useful to parse a JSON specification\nand add your custom data with `VegaLite.data_from_values/3`.","ref":"VegaLite.html#module-using-json-specification"},{"type":"module","title":"Options - VegaLite","doc":"Most `VegaLite` functions accept an optional list of options,\nwhich are converted directly as the specification properties.\nTo provide a more Elixir-friendly experience, the options\nare automatically normalized, so you can use keyword lists\nand snake-case atom keys. For example, if you specify\n`axis: [label_angle: -45]`, this library will automatically\nrewrite it `labelAngle`, which is the name used by the VegaLite\nspecification.","ref":"VegaLite.html#module-options"},{"type":"function","title":"VegaLite.concat/3","doc":"Builds a concatenated multi-view specification from\nthe given list of single view specifications.\n\nThe concat type must be either `:wrappable` (default), `:horizontal` or `:vertical`.","ref":"VegaLite.html#concat/3"},{"type":"function","title":"Examples - VegaLite.concat/3","doc":"Vl.new()\n    |> Vl.data_from_values(...)\n    |> Vl.concat([\n      Vl.new()\n      |> ...,\n      Vl.new()\n      |> ...,\n      Vl.new()\n      |> ...\n    ])\n\n    Vl.new()\n    |> Vl.data_from_values(...)\n    |> Vl.concat(\n      [\n        Vl.new()\n        |> ...,\n        Vl.new()\n        |> ...\n      ],\n      :horizontal\n    )\n\n\nSee [the docs](https://vega.github.io/vega-lite/docs/concat.html) for more details.","ref":"VegaLite.html#concat/3-examples"},{"type":"function","title":"VegaLite.config/2","doc":"Adds view configuration to the specification.\n\nConfiguration allows for setting general properties of the visualization.\n\nAll provided options are converted to configuration properties\nand merged with the existing configuration in a shallow manner.","ref":"VegaLite.html#config/2"},{"type":"function","title":"Examples - VegaLite.config/2","doc":"Vl.new()\n    |> ...\n    |> Vl.config(\n      view: [stroke: :transparent],\n      padding: 100,\n      background: \"#333333\"\n    )\n\n\nSee [the docs](https://vega.github.io/vega-lite/docs/config.html) for more details.","ref":"VegaLite.html#config/2-examples"},{"type":"function","title":"VegaLite.data/2","doc":"Sets data properties in the specification.\n\nDefining the data source is usually the first step\nwhen building a graphic. For most use cases it's preferable\nto use more specific functions like `data_from_url/3` or `data_from_values/3`.\n\nAll provided options are converted to data properties.","ref":"VegaLite.html#data/2"},{"type":"function","title":"Examples - VegaLite.data/2","doc":"Vl.new()\n    |> Vl.data(sequence: [start: 0, stop: 12.7, step: 0.1, as: \"x\"])\n    |> ...\n\n\nSee [the docs](https://vega.github.io/vega-lite/docs/data.html) for more details.","ref":"VegaLite.html#data/2-examples"},{"type":"function","title":"VegaLite.data_from_url/3","doc":"Sets data URL in the specification.\n\nThe URL should be accessible by whichever client renders\nthe specification, so preferably an absolute one.\n\nAll provided options are converted to data properties.","ref":"VegaLite.html#data_from_url/3"},{"type":"function","title":"Examples - VegaLite.data_from_url/3","doc":"Vl.new()\n    |> Vl.data_from_url(\"https://vega.github.io/editor/data/penguins.json\")\n    |> ...\n\n    Vl.new()\n    |> Vl.data_from_url(\"https://vega.github.io/editor/data/stocks.csv\", format: :csv)\n    |> ...\n\n\nSee [the docs](https://vega.github.io/vega-lite/docs/data.html#url) for more details.","ref":"VegaLite.html#data_from_url/3-examples"},{"type":"function","title":"VegaLite.data_from_values/3","doc":"Sets inline data in the specification.\n\nAny tabular data is accepted, as long as it adheres to the\n`Table.Reader` protocol.","ref":"VegaLite.html#data_from_values/3"},{"type":"function","title":"Options - VegaLite.data_from_values/3","doc":"* `:only` - specifies a subset of fields to pick from the data\n\nAll other options are converted to data properties.","ref":"VegaLite.html#data_from_values/3-options"},{"type":"function","title":"Examples - VegaLite.data_from_values/3","doc":"data = [\n      %{\"category\" => \"A\", \"score\" => 28},\n      %{\"category\" => \"B\", \"score\" => 55}\n    ]\n\n    Vl.new()\n    |> Vl.data_from_values(data)\n    |> ...\n\nNote that any tabular data is accepted, as long as it adheres\nto the `Table.Reader` protocol. For example that's how we can\npass individual series:\n\n    xs = 1..100\n    ys = 1..100\n\n    Vl.new()\n    |> Vl.data_from_values(x: xs, y: ys)\n    |> ...\n\nSee [the docs](https://vega.github.io/vega-lite/docs/data.html#inline) for more details.","ref":"VegaLite.html#data_from_values/3-examples"},{"type":"function","title":"VegaLite.datasets_from_values/2","doc":"Specifies top-level datasets.\n\nDatasets can be used as a data source further in the specification.\nThis is useful if you need to refer to the data in multiple places\nor use a `transform/2` like `:lookup`.\n\nDatasets should be a key-value enumerable, where key is the dataset\nname and value is tabular data as in `data_from_values/3`.","ref":"VegaLite.html#datasets_from_values/2"},{"type":"function","title":"Examples - VegaLite.datasets_from_values/2","doc":"results = [\n      %{\"category\" => \"A\", \"score\" => 28},\n      %{\"category\" => \"B\", \"score\" => 55}\n    ]\n\n    points = [\n      %{\"x\" => \"1\", \"y\" => 10},\n      %{\"x\" => \"2\", \"y\" => 100}\n    ]\n\n    Vl.new()\n    |> Vl.datasets_from_values(results: results, points: points)\n    # Use one of the data sets as the primary data\n    |> Vl.data(name: \"results\")\n    |> ...\n\n\nSee [the docs](https://vega.github.io/vega-lite/docs/data.html#datasets) for more details.","ref":"VegaLite.html#datasets_from_values/2-examples"},{"type":"function","title":"VegaLite.encode/3","doc":"Adds an encoding entry to the specification.\n\nVisual channel represents a property of a visual mark,\nfor instance the `:x` and `:y` channels specify where\na point should be placed.\nEncoding defines the source of values for those channels.\n\nIn most cases you want to map specific data field\nto visual channels, prefer the `encode_field/4` function for that.\n\nAll provided options are converted to channel properties.","ref":"VegaLite.html#encode/3"},{"type":"function","title":"Examples - VegaLite.encode/3","doc":"Vl.new()\n    |> Vl.encode(:x, value: 2)\n    |> ...\n\n    Vl.new()\n    |> Vl.encode(:y, aggregate: :count, type: :quantitative)\n    |> ...\n\n    Vl.new()\n    |> Vl.encode(:y, field: \"price\")\n    |> ...\n\nAlternatively, a list of property lists may be given:\n\n    Vl.new()\n    |> Vl.encode(:tooltip, [\n      [field: \"height\", type: :quantitative],\n      [field: \"width\", type: :quantitative]\n    ])\n    |> ...\n\nSee [the docs](https://vega.github.io/vega-lite/docs/encoding.html) for more details.","ref":"VegaLite.html#encode/3-examples"},{"type":"function","title":"VegaLite.encode_field/4","doc":"Adds field encoding entry to the specification.\n\nA shorthand for `encode/3`, mapping a data field to a visual channel.\n\nFor example, if the data has `\"price\"` and `\"time\"` fields,\nyou could map `\"time\"` to the `:x` channel and `\"price\"`\nto the `:y` channel. This, combined with a line mark,\nwould then result in price-over-time plot.\n\nAll provided options are converted to channel properties.","ref":"VegaLite.html#encode_field/4"},{"type":"function","title":"Types - VegaLite.encode_field/4","doc":"Field data type is automatically inferred, but oftentimes\nneeds to be specified explicitly to get the desired result.\nThe `:type` option can be either of:\n\n  * `:quantitative` - when the field expresses some kind of quantity, typically numerical\n\n  * `:temporal` - when the field represents a point in time\n\n  * `:nominal` - when the field represents a category\n\n  * `:ordinal` - when the field represents a ranked order.\n    It is similar to `:nominal`, but there is a clear order of values\n\n  * `:geojson` - when the field represents a geographic shape\n    adhering to the [GeoJSON](https://geojson.org) specification\n\nSee [the docs](https://vega.github.io/vega-lite/docs/type.html) for more details on types.","ref":"VegaLite.html#encode_field/4-types"},{"type":"function","title":"Examples - VegaLite.encode_field/4","doc":"Vl.new()\n    |> Vl.data_from_values(...)\n    |> Vl.mark(:point)\n    |> Vl.encode_field(:x, \"time\", type: :temporal)\n    |> Vl.encode_field(:y, \"price\", type: :quantitative)\n    |> Vl.encode_field(:color, \"country\", type: :nominal)\n    |> Vl.encode_field(:size, \"count\", type: :quantitative)\n    |> ...\n\n    Vl.new()\n    |> Vl.encode_field(:x, \"date\", time_unit: :month, title: \"Month\")\n    |> Vl.encode_field(:y, \"price\", type: :quantitative, aggregate: :mean, title: \"Mean product price\")\n    |> ...\n\n\nSee [the docs](https://vega.github.io/vega-lite/docs/encoding.html#field-def) for more details.","ref":"VegaLite.html#encode_field/4-examples"},{"type":"function","title":"VegaLite.encode_repeat/4","doc":"Adds repeated field encoding entry to the specification.\n\nA shorthand for `encode/3`, mapping a field to a visual channel,\nas given by the repeat operator.\n\nRepeat type must be either `:repeat`, `:row`, `:column` or `:layer`\nand correspond to the repeat definition.\n\nAll provided options are converted to channel properties.","ref":"VegaLite.html#encode_repeat/4"},{"type":"function","title":"Examples - VegaLite.encode_repeat/4","doc":"See `repeat/3` to see the full picture.\n\nSee [the docs](https://vega.github.io/vega-lite/docs/repeat.html) for more details.","ref":"VegaLite.html#encode_repeat/4-examples"},{"type":"function","title":"VegaLite.facet/3","doc":"Builds a facet multi-view specification from the given\nsingle-view template.\n\nFacet definition must be either a [field definition](https://vega.github.io/vega-lite/docs/facet.html#field-def)\nor a [row/column mapping](https://vega.github.io/vega-lite/docs/facet.html#mapping).\n\nNote that you can also create facet graphics by using\nthe `:facet`, `:column` and `:row` encoding channels.","ref":"VegaLite.html#facet/3"},{"type":"function","title":"Examples - VegaLite.facet/3","doc":"Vl.new()\n    |> Vl.data_from_values(...)\n    |> Vl.facet(\n      [field: \"country\"],\n      Vl.new()\n      |> Vl.mark(:bar)\n      |> Vl.encode_field(:x, ...)\n      |> Vl.encode_field(:y, ...)\n    )\n\n    Vl.new()\n    |> Vl.data_from_values(...)\n    |> Vl.facet(\n      [\n        row: [field: \"country\", title: \"Country\"],\n        column: [field: \"year\", title: \"Year\"]\n      ]\n      Vl.new()\n      |> Vl.mark(:bar)\n      |> Vl.encode_field(:x, ...)\n      |> Vl.encode_field(:y, ...)\n    )\n\n\nSee [the docs](https://vega.github.io/vega-lite/docs/facet.html#facet-operator) for more details.","ref":"VegaLite.html#facet/3-examples"},{"type":"function","title":"VegaLite.from_json/1","doc":"Parses the given Vega-Lite JSON specification\nand wraps in the `VegaLite` struct for further processing.","ref":"VegaLite.html#from_json/1"},{"type":"function","title":"Examples - VegaLite.from_json/1","doc":"Vl.from_json(\"\"\"\n    {\n      \"data\": { \"url\": \"https://vega.github.io/editor/data/cars.json\" },\n      \"mark\": \"point\",\n      \"encoding\": {\n        \"x\": { \"field\": \"Horsepower\", \"type\": \"quantitative\" },\n        \"y\": { \"field\": \"Miles_per_Gallon\", \"type\": \"quantitative\" }\n      }\n    }\n    \"\"\")\n\n\nSee [the docs](https://vega.github.io/vega-lite/docs/spec.html) for more details.","ref":"VegaLite.html#from_json/1-examples"},{"type":"function","title":"VegaLite.from_spec/1","doc":"Wraps the given Vega-Lite specification in the `VegaLite`\nstruct for further processing.\n\nThere is also `from_json/1` that handles JSON parsing for you.\n\nSee [the docs](https://vega.github.io/vega-lite/docs/spec.html) for more details.","ref":"VegaLite.html#from_spec/1"},{"type":"function","title":"VegaLite.layers/2","doc":"Builds a layered multi-view specification from the given\nlist of single view specifications.","ref":"VegaLite.html#layers/2"},{"type":"function","title":"Examples - VegaLite.layers/2","doc":"Vl.new()\n    |> Vl.data_from_values(...)\n    |> Vl.layers([\n      Vl.new()\n      |> Vl.mark(:line)\n      |> Vl.encode_field(:x, ...)\n      |> Vl.encode_field(:y, ...),\n      Vl.new()\n      |> Vl.mark(:rule)\n      |> Vl.encode_field(:y, ...)\n      |> Vl.encode(:size, value: 2)\n    ])\n\n    Vl.new()\n    |> Vl.data_from_values(...)\n    # Note: top-level data, encoding, transforms are inherited\n    # by the child views unless overridden\n    |> Vl.encode_field(:x, ...)\n    |> Vl.layers([\n      ...\n    ])\n\n\nSee [the docs](https://vega.github.io/vega-lite/docs/layer.html) for more details.","ref":"VegaLite.html#layers/2-examples"},{"type":"function","title":"VegaLite.mark/3","doc":"Sets mark type in the specification.\n\nMark is a predefined visual object like a point or a line.\nVisual properties of the mark are defined by encoding.\n\nAll provided options are converted to mark properties.","ref":"VegaLite.html#mark/3"},{"type":"function","title":"Examples - VegaLite.mark/3","doc":"Vl.new()\n    |> Vl.mark(:point)\n    |> ...\n\n    Vl.new()\n    |> Vl.mark(:point, tooltip: true)\n    |> ...\n\n\nSee [the docs](https://vega.github.io/vega-lite/docs/mark.html) for more details.","ref":"VegaLite.html#mark/3-examples"},{"type":"function","title":"VegaLite.new/1","doc":"Returns a new specification wrapped in the `VegaLite` struct.\n\nAll provided options are converted to top-level properties\nof the specification.","ref":"VegaLite.html#new/1"},{"type":"function","title":"Examples - VegaLite.new/1","doc":"Vl.new(\n      title: \"My graph\",\n      width: 200,\n      height: 200\n    )\n    |> ...\n\n\nSee [the docs](https://vega.github.io/vega-lite/docs/spec.html) for more details.","ref":"VegaLite.html#new/1-examples"},{"type":"function","title":"VegaLite.param/3","doc":"Adds a parameter to the specification.\n\nParameters are the basic building blocks for introducing\ninteractions to graphics.\n\nAll provided options are converted to parameter properties.","ref":"VegaLite.html#param/3"},{"type":"function","title":"Examples - VegaLite.param/3","doc":"Vl.new()\n    |> Vl.data_from_values(...)\n    |> Vl.concat([\n      Vl.new()\n      # Define a parameter named \"brush\", whose value is a user-selected interval on the x axis\n      |> Vl.param(\"brush\", select: [type: :interval, encodings: [:x]])\n      |> Vl.mark(:area)\n      |> Vl.encode_field(:x, \"date\", type: :temporal)\n      |> ...,\n      Vl.new()\n      |> Vl.mark(:area)\n      # Use the \"brush\" parameter value to limit the domain of this view\n      |> Vl.encode_field(:x, \"date\", type: :temporal, scale: [domain: [param: \"brush\"]])\n      |> ...\n    ])\n\n  Parameters can also be specified using UI inputs, or computed based\n  on other parameters:\n\n    Vl.new()\n    |> Vl.param(\"height\", value: 20, bind: [input: :range, min: 1, max: 100, step: 1])\n    |> Vl.param(\"halfHeight\", expr: \"height / 2\")\n    |> ...\n\nSee [the docs](https://vega.github.io/vega-lite/docs/parameter.html) for more details.","ref":"VegaLite.html#param/3-examples"},{"type":"function","title":"VegaLite.projection/2","doc":"Adds a projection spec to the specification.\n\nProjection maps longitude and latitude pairs to x, y coordinates.","ref":"VegaLite.html#projection/2"},{"type":"function","title":"Examples - VegaLite.projection/2","doc":"Vl.new()\n    |> Vl.data_from_values(...)\n    |> Vl.projection(type: :albers_usa)\n    |> Vl.mark(:circle)\n    |> Vl.encode_field(:longitude, \"longitude\", type: :quantitative)\n    |> Vl.encode_field(:latitude, \"latitude\", type: :quantitative)\n\n\nSee [the docs](https://vega.github.io/vega-lite/docs/projection.html) for more details.","ref":"VegaLite.html#projection/2-examples"},{"type":"function","title":"VegaLite.repeat/3","doc":"Builds a repeated multi-view specification from the given\nsingle-view template.\n\nRepeat definition must be either a list of fields\nor a [row/column/layer mapping](https://vega.github.io/vega-lite/docs/repeat.html#repeat-mapping).\nThen some channels can be bound to a repeated field using `encode_repeat/4`.","ref":"VegaLite.html#repeat/3"},{"type":"function","title":"Examples - VegaLite.repeat/3","doc":"# Simple repeat\n    Vl.new()\n    |> Vl.data_from_values(...)\n    |> Vl.repeat(\n      [\"temp_max\", \"precipitation\", \"wind\"],\n      Vl.new()\n      |> Vl.mark(:line)\n      |> Vl.encode_field(:x, \"date\", time_unit: :month)\n      # The graphic will be reapeated with :y mapped to \"temp_max\",\n      # \"precipitation\" and \"wind\" respectively\n      |> Vl.encode_repeat(:y, :repeat, aggregate: :mean)\n    )\n\n    # Grid repeat\n    Vl.new()\n    |> Vl.data_from_values(...)\n    |> Vl.repeat(\n      [\n        row: [\n          \"beak_length\",\n          \"beak_depth\",\n          \"flipper_length\",\n          \"body_mass\"\n        ],\n        column: [\n          \"body_mass\",\n          \"flipper_length\",\n          \"beak_depth\",\n          \"beak_length\"\n        ]\n      ],\n      Vl.new()\n      |> Vl.mark(:point)\n      # The graphic will be repeated for every combination of :x and :y\n      # taken from the :row and :column lists above\n      |> Vl.encode_repeat(:x, :column, type: :quantitative)\n      |> Vl.encode_repeat(:y, :row, type: :quantitative)\n    )\n\n\nSee [the docs](https://vega.github.io/vega-lite/docs/repeat.html) for more details.","ref":"VegaLite.html#repeat/3-examples"},{"type":"function","title":"VegaLite.resolve/3","doc":"Adds a resolve entry to the specification.\n\nResolution defines how multi-view graphics are combined\nwith regard to scales, axis and legend.","ref":"VegaLite.html#resolve/3"},{"type":"function","title":"Example - VegaLite.resolve/3","doc":"Vl.new()\n    |> Vl.data_from_values(...)\n    |> Vl.layers([\n      Vl.new()\n      |> ...,\n      Vl.new()\n      |> ...\n    ])\n    |> Vl.resolve(:scale, y: :independent)\n\n\nSee [the docs](https://vega.github.io/vega-lite/docs/resolve.html) for more details.","ref":"VegaLite.html#resolve/3-example"},{"type":"function","title":"VegaLite.to_spec/1","doc":"Returns the underlying Vega-Lite specification.\n\nThe result is a nested Elixir datastructure that serializes\nto Vega-Lite JSON specification.\n\nSee [the docs](https://vega.github.io/vega-lite/docs/spec.html) for more details.","ref":"VegaLite.html#to_spec/1"},{"type":"function","title":"VegaLite.transform/2","doc":"Adds a transformation to the specification.\n\nTransformation describes an operation on data,\nlike calculating new fields, aggregating or filtering.\n\nAll provided options are converted to transform properties.","ref":"VegaLite.html#transform/2"},{"type":"function","title":"Examples - VegaLite.transform/2","doc":"Vl.new()\n    |> Vl.data_from_values(...)\n    |> Vl.transform(calculate: \"sin(datum.x)\", as: \"sin_x\")\n    |> ...\n\n    Vl.new()\n    |> Vl.data_from_values(...)\n    |> Vl.transform(filter: \"datum.height > 150\")\n    |> ...\n\n    Vl.new()\n    |> Vl.data_from_values(...)\n    |> Vl.transform(regression: \"price\", on: \"date\")\n    |> ...\n\n\nSee [the docs](https://vega.github.io/vega-lite/docs/transform.html) for more details.","ref":"VegaLite.html#transform/2-examples"},{"type":"type","title":"VegaLite.spec/0","doc":"","ref":"VegaLite.html#t:spec/0"},{"type":"type","title":"VegaLite.t/0","doc":"","ref":"VegaLite.html#t:t/0"},{"type":"module","title":"VegaLite.Data","doc":"Data is a VegaLite module designed to provide a shorthand API for charts based on data.\n\nIt relies on internal type inference, and although all options can be overridden,\nonly data that implements the `Table.Reader` protocol is supported.","ref":"VegaLite.Data.html"},{"type":"function","title":"VegaLite.Data.chart/3","doc":"Returns the specification for the a given data, a mark, and a list of\nfields to be encoded.\n\nThe `mark` is either an atom, such as `:line`, or a keyword list such as\n`[type: :point, line: true]`.\n\nIt encodes only the given fields from the data by default. More fields can\nbe added using the `:extra_fields` option. All the other fields must follow\nthe specifications of the `VegaLite` module.","ref":"VegaLite.Data.html#chart/3"},{"type":"function","title":"Options - VegaLite.Data.chart/3","doc":"* `:extra_fields` - adds extra fields to the data subset for later use","ref":"VegaLite.Data.html#chart/3-options"},{"type":"function","title":"Examples - VegaLite.Data.chart/3","doc":"data = [\n      %{\"category\" => \"A\", \"score\" => 28},\n      %{\"category\" => \"B\", \"score\" => 55}\n    ]\n\n    Data.chart(data, :bar, x: \"category\", y: \"score\")\n\n    Data.chart(data, :bar, x: \"category\", extra_fields: [\"score\"])\n    |> Vl.encode_field(:y, \"score\", type: :quantitative)\n\nThe above examples achieves the same results as the example below.\n\n    Vl.new()\n    |> Vl.data_from_values(data, only: [\"category\", \"score\"])\n    |> Vl.mark(:bar)\n    |> Vl.encode_field(:x, \"category\", type: :nominal)\n    |> Vl.encode_field(:y, \"score\", type: :quantitative)\n\nThis function may also be called with an existing VegaLite spec and\nwithout a mark:\n\n    Vl.new()\n    |> Vl.mark(:bar)\n    |> Data.chart(data, x: \"category\", extra_fields: [\"score\"])\n\nIn such cases it is your responsibility to encode the mark.","ref":"VegaLite.Data.html#chart/3-examples"},{"type":"function","title":"VegaLite.Data.chart/4","doc":"Same as chart/3 but receives a valid `VegaLite` specification as a first argument.","ref":"VegaLite.Data.html#chart/4"},{"type":"function","title":"Examples - VegaLite.Data.chart/4","doc":"data = [\n      %{\"category\" => \"A\", \"score\" => 28},\n      %{\"category\" => \"B\", \"score\" => 55}\n    ]\n\n    Vl.new(title: \"With title\")\n    |> Data.chart(data, :bar, x: \"category\", y: \"score\")\n\n    Vl.new(title: \"With title\")\n    |> Vl.mark(:bar)\n    |> Data.chart(data, x: \"category\", y: \"score\")\n\nThe above example achieves the same results as the example below.\n\n    Vl.new(title: \"With title\")\n    |> Vl.data_from_values(data, only: [\"category\", \"score\"])\n    |> Vl.mark(:bar)\n    |> Vl.encode_field(:x, \"category\", type: :nominal)\n    |> Vl.encode_field(:y, \"score\", type: :quantitative)","ref":"VegaLite.Data.html#chart/4-examples"},{"type":"function","title":"VegaLite.Data.columns_for/1","doc":"Returns a map with each column and its respective inferred type for the given data.","ref":"VegaLite.Data.html#columns_for/1"},{"type":"module","title":"VegaLite.Export","doc":"Various export methods for a `VegaLite` specification.\n\nAll of the export functions depend on the `:jason` package.\nAdditionally the PNG, SVG and PDF exports rely on npm packages,\nso you will need Node.js, `npm`, and the following dependencies:\n\n```console\n$ npm install -g vega vega-lite canvas\n```\n\nAlternatively you can install the dependencies in a local directory:\n\n```console\n$ npm install vega vega-lite canvas\n```","ref":"VegaLite.Export.html"},{"type":"function","title":"VegaLite.Export.run_cmd/2","doc":"","ref":"VegaLite.Export.html#run_cmd/2"},{"type":"function","title":"VegaLite.Export.save!/3","doc":"Saves a `VegaLite` specification to file in one of\nthe supported formats.","ref":"VegaLite.Export.html#save!/3"},{"type":"function","title":"Options - VegaLite.Export.save!/3","doc":"* `:format` - the format to export the graphic as,\n    must be either of: `:json`, `:html`, `:png`, `:svg`, `:pdf`.\n    By default the format is inferred from the file extension.\n\n  * `:local_npm_prefix` - a relative path pointing to a local npm project directory\n    where the necessary npm packages are installed. For instance, in Phoenix projects\n    you may want to pass `local_npm_prefix: \"assets\"`. By default the npm packages\n    are searched for in the current directory and globally.","ref":"VegaLite.Export.html#save!/3-options"},{"type":"function","title":"VegaLite.Export.to_html/1","doc":"Builds an HTML page that renders the given graphic.\n\nThe HTML page loads necessary JavaScript dependencies from a CDN\nand then renders the graphic in a root element.","ref":"VegaLite.Export.html#to_html/1"},{"type":"function","title":"VegaLite.Export.to_json/1","doc":"Returns the underlying Vega-Lite specification as JSON.","ref":"VegaLite.Export.html#to_json/1"},{"type":"function","title":"VegaLite.Export.to_pdf/2","doc":"Renders the given graphic into a PDF and returns its\nbinary content.\n\nRelies on the `npm` packages mentioned above.","ref":"VegaLite.Export.html#to_pdf/2"},{"type":"function","title":"Options - VegaLite.Export.to_pdf/2","doc":"* `:local_npm_prefix` - a relative path pointing to a local npm project directory\n    where the necessary npm packages are installed. For instance, in Phoenix projects\n    you may want to pass `local_npm_prefix: \"assets\"`. By default the npm packages\n    are searched for in the current directory and globally.","ref":"VegaLite.Export.html#to_pdf/2-options"},{"type":"function","title":"VegaLite.Export.to_png/2","doc":"Renders the given graphic as a PNG image and returns\nits binary content.\n\nRelies on the `npm` packages mentioned above.","ref":"VegaLite.Export.html#to_png/2"},{"type":"function","title":"Options - VegaLite.Export.to_png/2","doc":"* `:local_npm_prefix` - a relative path pointing to a local npm project directory\n    where the necessary npm packages are installed. For instance, in Phoenix projects\n    you may want to pass `local_npm_prefix: \"assets\"`. By default the npm packages\n    are searched for in the current directory and globally.","ref":"VegaLite.Export.html#to_png/2-options"},{"type":"function","title":"VegaLite.Export.to_svg/2","doc":"Renders the given graphic as an SVG image and returns\nits binary content.\n\nRelies on the `npm` packages mentioned above.","ref":"VegaLite.Export.html#to_svg/2"},{"type":"function","title":"Options - VegaLite.Export.to_svg/2","doc":"* `:local_npm_prefix` - a relative path pointing to a local npm project directory\n    where the necessary npm packages are installed. For instance, in Phoenix projects\n    you may want to pass `local_npm_prefix: \"assets\"`. By default the npm packages\n    are searched for in the current directory and globally.","ref":"VegaLite.Export.html#to_svg/2-options"},{"type":"module","title":"VegaLite.Viewer","doc":"Graphics rendering using Erlang's `:wx` bindings.\n\nThis method is useful for viewing graphics in scripts\nand IEx sessions. Note it requires Erlang/OTP 24+ with\na recent WxWidgets installation with webview support.","ref":"VegaLite.Viewer.html"},{"type":"function","title":"VegaLite.Viewer.show/1","doc":"Renders a `VegaLite` specification in GUI window widget.\n\nRequires Erlang compilation to include the `:wx` module.","ref":"VegaLite.Viewer.html#show/1"},{"type":"function","title":"VegaLite.Viewer.show_and_wait/1","doc":"Same as `show/1`, but blocks until the window widget is closed.","ref":"VegaLite.Viewer.html#show_and_wait/1"}],"content_type":"text/markdown"}